@@ -3,31 +3,13 @@ import platform
 import pytest
 
 from click import ClickException
-
-from cnctcli import get_version
+from cnct import ClientError
 from cnctcli.api.utils import (
     format_http_status,
-    get_headers,
     handle_http_error,
 )
 
 
-def test_get_headers():
-    headers = get_headers('MY API KEY')
-
-    assert 'Authorization' in headers
-    assert headers['Authorization'] == 'MY API KEY'
-    assert 'User-Agent' in headers
-
-    ua = headers['User-Agent']
-
-    cli, python, system = ua.split()
-
-    assert cli == f'connect-cli/{get_version()}'
-    assert python == f'{platform.python_implementation()}/{platform.python_version()}'
-    assert system == f'{platform.system()}/{platform.release()}'
-
-
 def test_format_http_status():
     assert format_http_status(401) == '401 - Unauthorized'
     assert format_http_status(404) == '404 - Not Found'
@@ -38,10 +20,10 @@ def test_format_http_status():
 
 
 def test_handle_http_error_400(mocker):
-    res = mocker.MagicMock()
+    res = ClientError()
     res.status_code = 400
-    res.json = lambda: {'error_code': 'SYS-000', 'errors': ['error1', 'error2']}
-
+    res.errors = ['error1', 'error2']
+    res.error_code = 'SYS-000'
     with pytest.raises(ClickException) as e:
         handle_http_error(res)
 
